@@ -39,7 +39,7 @@ Effect type  | Description
 """
 
 
-import sys
+import logging
 from dataclasses import dataclass
 
 import pyensembl
@@ -49,6 +49,8 @@ from varcode.effects import Intergenic
 
 from . import effect_ordering
 
+logging.getLogger("pyensembl").setLevel(logging.WARNING)
+
 IUPAC = {
     "A": ["A"],
     "C": ["C"],
